%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
%%%  FUNCTION:  bior97_norm
%%%
%%%  INPUTS:    NONE
%%%
%%%  OUTPUTS:   lo_d                - low-pass decomposotion filter
%%%
%%%             hi_d                - high-pass decomposition filter
%%%
%%%             lo_r                - low-pass reconstruction filter
%%%
%%%             hi_r                - high-pass reconstruction filter
%%%
%%%  CHANGES:   NONE
%%%
%%%  NOTES:     Computes analysis and synthesis filters for a 9/7 biorthogonal
%%%             wavelet transfiorm.
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%  Author:    Matthew Gaubatz
%%%  Version:   1.0
%%%  Date:      01/05/2007
%%%  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%  Copyright (c) 2007 Visual Communications Lab, Cornell University
%%%  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%  Permission to use, copy, modify, distribute and sell this software
%%%  and its documentation for any purpose is hereby granted without fee,
%%%  provided that the above copyright notice appear in all copies and
%%%  that both that copyright notice and this permission notice appear
%%%  in supporting documentation.  VCL makes no representations about
%%%  the suitability of this software for any purpose.
%%%  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%  DISCLAIMER:
%%%  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%  The code provided hereunder is provided as is without warranty
%%%  of any kind, either express or implied, including but not limited
%%%  to the implied warranties of merchantability and fitness for a
%%%  particular purpose.  The author(s) shall in no event be liable for
%%%  any damages whatsoever including direct, indirect, incidental,
%%%  consequential, loss of business profits or special damages.
%%%  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%  This function is obtained by altering 'bior97.m' code written by Matthew Gaubatz
%%%  altered by: Murat Demirtas
%%%  10/22/2013
%%%  9/7 Bi-orthogonal analysis and synthesis filter coefficents have been altered
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [lo_d,hi_d,lo_r,hi_r] = bior97_norm

lo_d(1) =  0.6029490182363579;
lo_d(2) =  0.2668641184428723;
lo_d(3) = -0.07822326652898785;
lo_d(4) = -0.01686411844287495;
lo_d(5) =  0.026748741080976;

hi_d(1) = 1.115087052456994;
hi_d(2) =  -0.5912717631142470;
hi_d(3) =  -0.05754352622849957;
hi_d(4) = 0.09127176311424948;
hi_d(5) = 0;

hi_r = [lo_d(1) -lo_d(2) lo_d(3) -lo_d(4) lo_d(5)];
lo_r = [hi_d(1) -hi_d(2) hi_d(3) -hi_d(4) hi_d(5)];

lo_d = [fliplr(lo_d(2:end)) lo_d];
hi_d = [fliplr(hi_d(2:end)) hi_d];
lo_r = [fliplr(lo_r(2:end)) lo_r];
hi_r = [fliplr(hi_r(2:end)) hi_r];